#!/bin/sh
# This is part of the acl-installer program: 
#    http://kevin.rosenberg.net/acl-installer
#
# Copyright (c) 2002 Kevin M. Rosenberg
#
# acl-installer is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License (version 2) as
# published by the Free Software Foundation.
#
# acl-installer is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have a copy of the GNU General Public License on your
# Debian system in the file /usr/share/common-licenses/GPL-2

set -e

acl_dir="/usr/lib/acl-pro"  # This value will be set by template processor
if [ -z "$acl_dir" ]; then
  echo "Error: the variable acl_dir is not defined in $0" >&2
  exit 1;
fi

download_patches()
{
    if [ "$(ping -q -c 2 ftp.franz.com >|/dev/null && echo ok)" = ok ]; then
	${acl_dir}/alisp -qq -batch -e "(si:update-allegro)" -kill
    else
	echo "Unable to find ftp.franz.com on network. Skipping patch download." >& 2
    fi
}

# This is required for acl-installer, but not acl-pro-installer
add_to_update_sh()
{
    # check that using acl-installer image
    if [ -f $acl_dir/acl.dxl ]; then
	output=`grep "^images=" $acl_dir/update.sh | grep "acl.dxl" || true`
	if [ ! "$output" ]; then
	    mv $acl_dir/update.sh $acl_dir/update-orig.sh
	    sed -e "s@^images\=\"@images\=\"acl.dxl @;" < $acl_dir/update-orig.sh > ${acl_dir}/update.sh
	    chmod +x $acl_dir/update.sh 
	fi
    fi
}

install_patches()
{
    cd $acl_dir
    ./update.sh
}

install_clc()
{
    cd $acl_dir
    installs=`echo `
    for i in install-clc-*.cl; do
	if [ -f $i ]; then
	    impl=$(echo $i | sed 's/install-clc-\(.*\).cl/\1/')
	    clc_bin=/usr/lib/common-lisp/bin
	    if [ -x $clc_bin/${impl}.sh ]; then
		/usr/lib/common-lisp/bin/${impl}.sh install-clc
	    else
		echo "Can't find implementation binary $clc_bin/${impl}.sh to rebuild clc" >& 2
	    fi
	fi
    done
}

case "$1" in
    remove-clc)
	install_patches
	;;
    initial-installation)
	download_patches
	add_to_update_sh
	install_patches
	;;
    *)
	# This is typically called by the user who wants to update his
	# image. So, it should reinstall clc since install_patches
	# will reset to the original distributed image plus patches.
	echo "Downloading and installing patches" >&2 
	download_patches
	add_to_update_sh
	install_patches
	install_clc
	;;
esac
